@@ -11,14 +11,18 @@ class Lancelot__PassagewayViewHandler(Lancelot__Panel.Lancelot__PanelHandler):
         includesCode = ""
         for include in includes:
             if (include != ""):
-                includesCode = "#include<" + include + ">\n"
+                includesCode += "#include<" + include + ">\n"
         return includesCode
 
 
     def setup(self):
         setup = Lancelot__Panel.Lancelot__PanelHandler.setup(self)
 
-        
+
+        if self.hasAttribute('activationMethod'):
+            setup += self.attribute('name') \
+                  + '->setActivationMethod(' + self.attribute('activationMethod') + ');'
+
 
         return setup;
 
