@@ -11,14 +11,14 @@ class QGraphicsLayoutHandler(QGraphicsLayoutItem.QGraphicsLayoutItemHandler):
         includesCode = ""
         for include in includes:
             if (include != ""):
-                includesCode = "#include<" + include + ">\n"
+                includesCode += "#include<" + include + ">\n"
         return includesCode
 
 
     def setup(self):
         setup = QGraphicsLayoutItem.QGraphicsLayoutItemHandler.setup(self)
 
-        
+
 
         return setup;
 
